=======
Notepad
=======

.. contents::
   :local:
   :depth: 2

----

*******
Devices
*******

RFM69-based
===========
- https://harizanov.com/product/funky-v3/
- http://hackaday.com/2015/11/14/rfm69-to-mqtt-gateway-on-the-super-cheap/
- https://harizanov.com/2015/11/rfm69-to-mqtt-gateway-using-esp8266/
- https://harizanov.com/2015/11/rfm69-to-mqtt-gateway-using-esp8266/rfm69_serial_console/

****
Misc
****


- http://iotf-beta.readthedocs.org/
- http://iotf-beta.readthedocs.org/en/latest/reference/mqtt/

- TheThingsNetwork and LoRA

- https://github.com/phodal/awesome-iot

- | TinyOS
  | http://tinyos.net/
  | https://github.com/tinyos/tinyos-main
  | https://lakshbhatia.wordpress.com/

- | Contiki OS
  | The Open Source OS for the Internet of Things
  | http://www.contiki-os.org/
  | http://www.contiki-os.org/hardware.html

- http://postscapes.com/internet-of-things-software-guide
    - http://openalerts.org/
    - http://iot-toolkit.com/
    - http://thethingsystem.com/
        - https://github.com/TheThingSystem
        - https://github.com/TheThingSystem/steward

- | Data ingestion and consumption platform, uses MongoDB
  | http://nitrogen.io/

- | http://thethingsystem.com/
  | http://thethingsystem.com/dev/Simple-Thing-Protocol.html
  | http://thethingsystem.com/dev/Thing-Sensor-Reporting-Protocol.html

- http://opensourcerf.com/

- | Evolution of the Internet Architecture for LoWPAN
  | http://ubimob2013.sciencesconf.org/19139/document

- https://github.com/Stefan-Schmidt/lowpan-tools

- http://www.zigbee.org/
- https://en.wikipedia.org/wiki/ZigBee
- https://de.wikipedia.org/wiki/ZigBee
- http://www.digi.com/resources/standards-and-technologies/rfmodems/wireless-zigbee
- https://de.wikipedia.org/wiki/Z-Wave
- https://de.wikipedia.org/wiki/Enocean
- https://en.wikipedia.org/wiki/XBee
- http://www.digi.com/lp/xbee
- https://en.wikipedia.org/wiki/IEEE_802.15.4
- https://en.wikipedia.org/wiki/Thread_(network_protocol)
- https://en.wikipedia.org/wiki/Contiki
- https://en.wikipedia.org/wiki/UIP_(micro_IP)


* RPL: IPv6 Routing Protocol for Low-Power and Lossy Networks for Linux
  * https://github.com/joaopedrotaveira/linux-rpl
  * https://github.com/joaopedrotaveira/rpl-userspace-tools
* https://github.com/telecombretagne/Arduino-IPv6Stack
* https://github.com/linux-wpan/ieee802154-serial-protocol-version2

- https://aws.amazon.com/iot/

- http://www.seeedstudio.com/wiki/LinkIt_ONE
- http://home.labs.mediatek.com/
- http://www.instructables.com/id/Linkit-one-View-All-Analog-data-using-Mobile-WIFI-/

